@@ -8,8 +8,8 @@
 #' @param h A numeric vector of length one or number of classes in y. If one is
 #' given, all classes will have same shrink factor. If a value is given for each
 #' classes, it will match respectively to \code{levels(y)}. Default is 1.
-#' @param n_needed vector of desired number of synthetic samples for each class.
-#' A vector of integers for each class. Default is NULL meaning full balance.
+#' @param ovRate Oversampling rate multiplied by the difference between maximum
+#' and other of class sizes. Default is 1 meaning full balance.
 #'
 #' @details
 #' Randomly Over Sampling Examples (ROSE) (Menardi and Torelli, 2014) is an
@@ -54,7 +54,7 @@ ROSE <- function(
     x,
     y,
     h = 1,
-    n_needed = NULL) {
+    ovRate = 1) {
 
   if (!is.data.frame(x) & !is.matrix(x)) {
     stop("x must be a matrix or dataframe")
@@ -87,12 +87,7 @@ ROSE <- function(
   x_classes <- lapply(class_names, function(m) x[y == m,, drop = FALSE])
   n_classes <- sapply(class_names, function(m) sum(y == m))
 
-  if (is.null(n_needed)) {
-    n_needed <- rep(round(n/k_class), k_class)
-  }
-  if (length(n_needed) != k_class) {
-    stop("n_needed must be an integer vector matching the number of classes.")
-  }
+  n_needed <- round((max(n_classes) - n_classes)*ovRate)
 
   i_new_classes <- lapply(1:k_class, function(m) {
     sample(1:n_classes[m], n_needed[m], replace = TRUE)
@@ -126,18 +121,20 @@ ROSE <- function(
     x_noise_classes[[m]] + x_classes[[m]][i_new_classes[[m]],,drop = FALSE]
   })
 
-  x_new <- do.call(rbind, x_new_classes)
+  x_syn <- do.call(rbind, x_new_classes)
+  x_new <- rbind(x, x_syn)
 
-  y_new <- factor(unlist(sapply(1:k_class, function(m) {
+  y_syn <- factor(unlist(sapply(1:k_class, function(m) {
     rep(class_names[m], n_needed[m])
   })), levels = class_names, labels = class_names)
+  y_new <- c(y, y_syn)
 
   colnames(x_new) <- var_names
 
   return(list(
     x_new = x_new,
     y_new = y_new,
-    x_syn = x_new,
-    y_syn = y_new
+    x_syn = x_syn,
+    y_syn = y_syn
   ))
 }
